@@ -43,7 +43,7 @@ import itertools
 import logging
 import operator
 
-import subprocess
+from vdsm.common.compat import subprocess
 
 LSBLK = "/usr/bin/lsblk"
 LVM = "/usr/sbin/lvm"
@@ -55,10 +55,6 @@ MountInfo = collections.namedtuple("MountInfo", "lv,mountpoint,devices")
 FilterItem = collections.namedtuple("FilterItem", "action,path")
 Advice = collections.namedtuple("Advice", "action,filter")
 
-# We use this tag to detect a mounted ovirt storage domain - typically the
-# master lv of a block storage domain.
-OVIRT_VG_TAG = "RHAT_storage_domain"
-
 # Advice actions
 
 # The host is already configured, no action is needed.
@@ -129,11 +125,7 @@ def find_lvm_mounts():
     for devtype, name, mountpoint in rows:
         if devtype != "lvm" or mountpoint == "":
             continue
-        vg_name, tags = vg_info(name)
-        if OVIRT_VG_TAG in tags:
-            log.debug("Skipping oVirt logical volume %r", name)
-            continue
-        devices = vg_devices(vg_name)
+        devices = find_lv_devices(name)
         mounts.append(MountInfo(name, mountpoint, devices))
 
     # Keep sorted for easy testing.
@@ -278,43 +270,27 @@ def format_option(items):
     return "filter = [ {} ]".format(", ".join(quoted))
 
 
-def vg_info(lv_path):
+def find_lv_devices(lv_path):
     """
     Returns list of devices used by lv lv_path.
     """
-    log.debug("Looking up information for logical volume %r", lv_path)
+    log.debug("Looking up volume group for logical volume %r", lv_path)
     out = _run([
         LVM,
         "lvs",
         "--noheadings",
         "--readonly",
-        # If the host was already configured, the lvm filter hides the devices
-        # of the mounted master lv, and lvs will fail. Use a permissive filter
-        # to avoid this.
-        "--config", 'devices {filter=["a|.*|"]}',
-        "--options", "vg_name,vg_tags",
+        "--options",
+        "vg_name",
         lv_path
     ])
-    # Format is: space space vg_name space tag,tag... newline
-    out = out.lstrip().rstrip("\n")
-    vg_name, vg_tags = out.split(" ", 1)
-    vg_tags = vg_tags.split(",")
-    return vg_name, vg_tags
-
-
-def vg_devices(vg_name):
-    """
-    Returns list of devices used by vg vg_name.
-    """
+    vg_name = out.strip()
     log.debug("Looking up volume group %r devices", vg_name)
     out = _run([
         LVM,
         "vgs",
         "--noheadings",
         "--readonly",
-        # If the host has an incorrect filter, some devices needed by the host
-        # may be hidden, preventing creating of a new correct filter.
-        "--config", 'devices {filter=["a|.*|"]}',
         "--options", "pv_name",
         vg_name
     ])
@@ -334,7 +310,6 @@ def _run(args):
         Command output decoded using utf-8.
     """
     log.debug("Running %s", args)
-    # Using standard subprocess module, explicit close_fds needed.
-    out = subprocess.check_output(args, close_fds=True)
+    out = subprocess.check_output(args)
     log.debug("Completed successfuly, out=%r", out)
     return out.decode("utf-8")
